@@ -23,11 +23,12 @@ func IsBoolSet(b *bool) bool {
 }
 
 func isStringSet(s *string) bool {
-	return s != nil && len(*s) > 0
+	return s != nil && *s != ""
 }
 
 func isYamlFile(file string) bool {
 	ext := filepath.Ext(file)
+
 	return ext == ".yml" || ext == ".yaml"
 }
 
