@@ -26,6 +26,7 @@ import (
 	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/tcell/v2"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/labels"
 	"k8s.io/apimachinery/pkg/util/sets"
 )
 
@@ -173,7 +174,12 @@ func (b *Browser) Start() {
 	b.Table.Start()
 	b.CmdBuff().AddListener(b)
 	if err := b.GetModel().Watch(b.prepareContext()); err != nil {
-		b.App().Flash().Errf("Watcher failed for %s -- %s", b.GVR(), err)
+		go func() {
+			time.Sleep(500 * time.Millisecond)
+			b.app.QueueUpdateDraw(func() {
+				b.App().Flash().Errf("Watcher failed for %s -- %s", b.GVR(), err)
+			})
+		}()
 	}
 }
 
@@ -194,9 +200,11 @@ func (b *Browser) SetFilter(s string) {
 	b.CmdBuff().SetText(s, "")
 }
 
-func (b *Browser) SetLabelFilter(labels map[string]string) {
-	b.CmdBuff().SetText(toLabelsStr(labels), "")
-	b.GetModel().SetLabelFilter(toLabelsStr(labels))
+func (b *Browser) SetLabelSelector(sel labels.Selector) {
+	if sel != nil {
+		b.CmdBuff().SetText(sel.String(), "")
+	}
+	b.GetModel().SetLabelSelector(sel)
 }
 
 // BufferChanged indicates the buffer was changed.
@@ -205,9 +213,11 @@ func (*Browser) BufferChanged(_, _ string) {}
 // BufferCompleted indicates input was accepted.
 func (b *Browser) BufferCompleted(text, _ string) {
 	if internal.IsLabelSelector(text) {
-		b.GetModel().SetLabelFilter(ui.TrimLabelSelector(text))
+		if sel, err := ui.TrimLabelSelector(text); err == nil {
+			b.GetModel().SetLabelSelector(sel)
+		}
 	} else {
-		b.GetModel().SetLabelFilter("")
+		b.GetModel().SetLabelSelector(labels.Everything())
 	}
 }
 
@@ -330,7 +340,11 @@ func (b *Browser) TableDataChanged(mdata *model1.TableData) {
 		b.setUpdating(true)
 		defer b.setUpdating(false)
 		if b.GetColumnCount() == 0 {
-			b.app.Flash().Infof("Viewing %s in namespace %s", b.GVR(), client.PrintNamespace(b.GetNamespace()))
+			if client.IsClusterScoped(b.GetNamespace()) {
+				b.app.Flash().Infof("Viewing %s...", b.GVR())
+			} else {
+				b.app.Flash().Infof("Viewing %s in namespace %s", b.GVR(), client.PrintNamespace(b.GetNamespace()))
+			}
 		}
 		b.refreshActions()
 		b.UpdateUI(cdata, mdata)
@@ -375,7 +389,7 @@ func (b *Browser) resetCmd(evt *tcell.EventKey) *tcell.EventKey {
 		hasFilter := !b.CmdBuff().Empty()
 		b.CmdBuff().ClearText(false)
 		if hasFilter {
-			b.GetModel().SetLabelFilter("")
+			b.GetModel().SetLabelSelector(labels.Everything())
 			b.Refresh()
 		}
 		return b.App().PrevCmd(evt)
@@ -513,7 +527,7 @@ func (b *Browser) switchNamespaceCmd(evt *tcell.EventKey) *tcell.EventKey {
 	auth, err := b.App().factory.Client().CanI(ns, b.GVR(), "", client.ListAccess)
 	if !auth {
 		if err == nil {
-			err = fmt.Errorf("current user can't access namespace %s", ns)
+			err = fmt.Errorf("access denied for user on: %s/%s", ns, b.GVR())
 		}
 		b.App().Flash().Err(err)
 		return nil
@@ -524,7 +538,11 @@ func (b *Browser) switchNamespaceCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return nil
 	}
 	b.setNamespace(ns)
-	b.app.Flash().Infof("Viewing %s in namespace `%s`...", b.GVR(), client.PrintNamespace(ns))
+	if client.IsClusterScoped(ns) {
+		b.app.Flash().Infof("Viewing %s...", b.GVR())
+	} else {
+		b.app.Flash().Infof("Viewing %s in namespace `%s`...", b.GVR(), client.PrintNamespace(ns))
+	}
 	b.refresh()
 	b.UpdateTitle()
 	b.SelectRow(1, 0, true)
@@ -555,7 +573,9 @@ func (b *Browser) defaultContext() context.Context {
 	ctx = context.WithValue(ctx, internal.KeyGVR, b.GVR())
 	ctx = context.WithValue(ctx, internal.KeyPath, b.Path)
 	if internal.IsLabelSelector(b.CmdBuff().GetText()) {
-		ctx = context.WithValue(ctx, internal.KeyLabels, ui.TrimLabelSelector(b.CmdBuff().GetText()))
+		if sel, err := ui.TrimLabelSelector(b.CmdBuff().GetText()); err == nil {
+			ctx = context.WithValue(ctx, internal.KeyLabels, sel)
+		}
 	}
 	ctx = context.WithValue(ctx, internal.KeyNamespace, client.CleanseNamespace(b.App().Config.ActiveNamespace()))
 	ctx = context.WithValue(ctx, internal.KeyWithMetrics, b.app.factory.Client().HasMetrics())
@@ -621,9 +641,12 @@ func (b *Browser) namespaceActions(aa *ui.KeyActions) {
 	aa.Add(ui.KeyN, ui.NewKeyAction("Copy Namespace", b.cpNsCmd, false))
 
 	b.namespaces = make(map[int]string, data.MaxFavoritesNS)
-	aa.Add(ui.Key0, ui.NewKeyAction(client.NamespaceAll, b.switchNamespaceCmd, true))
-	b.namespaces[0] = client.NamespaceAll
-	index := 1
+	var index int
+	if ok, _ := b.app.Conn().CanI(client.NamespaceAll, client.NsGVR, "", client.ListAccess); ok {
+		aa.Add(ui.Key0, ui.NewKeyAction(client.NamespaceAll, b.switchNamespaceCmd, true))
+		b.namespaces[0] = client.NamespaceAll
+		index = 1
+	}
 	favNamespaces := b.app.Config.FavNamespaces()
 	for _, ns := range favNamespaces {
 		if ns == client.NamespaceAll {
