@@ -29,21 +29,17 @@ func NewInterpreter(s string) *Interpreter {
 
 // ClearNS clears the current namespace if any.
 func (c *Interpreter) ClearNS() {
-	if !c.HasNS() {
-		return
-	}
-	if ons, ok := c.NSArg(); ok {
-		c.Reset(strings.TrimSpace(strings.Replace(c.line, " "+ons, "", 1)))
-	}
+	c.SwitchNS(client.BlankNamespace)
 }
 
 // SwitchNS replaces the current namespace with the provided one.
 func (c *Interpreter) SwitchNS(ns string) {
-	if !c.HasNS() {
-		c.Reset(c.line + " " + ns)
+	if ons, ok := c.NSArg(); ok && ons != client.BlankNamespace {
+		c.Reset(strings.TrimSpace(strings.Replace(c.line, " "+ons, " "+ns, 1)))
+		return
 	}
-	if ons, ok := c.NSArg(); ok {
-		c.Reset(strings.TrimSpace(strings.Replace(c.line, ons, ns, 1)))
+	if ns != client.BlankNamespace {
+		c.Reset(strings.TrimSpace(c.line) + " " + ns)
 	}
 }
 
@@ -196,7 +192,7 @@ func (c *Interpreter) RBACArgs() (subject, verb string, ok bool) {
 	return
 }
 
-// XRayArgs return the gvr and ns if any.
+// XrayArgs return the gvr and ns if any.
 func (c *Interpreter) XrayArgs() (cmd, namespace string, ok bool) {
 	if !c.IsXrayCmd() {
 		return
