@@ -92,7 +92,7 @@ func (n *Node) bindKeys(aa *ui.KeyActions) {
 }
 
 func (n *Node) showPods(a *App, _ ui.Tabular, _ *client.GVR, path string) {
-	showPods(a, n.GetTable().GetSelectedItem(), client.BlankNamespace, "spec.nodeName="+path)
+	showPods(a, n.GetTable().GetSelectedItem(), nil, "spec.nodeName="+path)
 }
 
 func (n *Node) drainCmd(evt *tcell.EventKey) *tcell.EventKey {
