@@ -5,7 +5,6 @@ package view
 
 import (
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/tcell/v2"
 )
@@ -16,7 +15,7 @@ type PriorityClass struct {
 }
 
 // NewPriorityClass returns a new viewer.
-func NewPriorityClass(gvr client.GVR) ResourceViewer {
+func NewPriorityClass(gvr *client.GVR) ResourceViewer {
 	s := PriorityClass{
 		ResourceViewer: NewBrowser(gvr),
 	}
@@ -30,5 +29,5 @@ func (s *PriorityClass) bindKeys(aa *ui.KeyActions) {
 }
 
 func (s *PriorityClass) refCmd(evt *tcell.EventKey) *tcell.EventKey {
-	return scanRefs(evt, s.App(), s.GetTable(), dao.PcGVR)
+	return scanRefs(evt, s.App(), s.GetTable(), client.PcGVR)
 }
