@@ -15,7 +15,7 @@ import (
 func TestReferenceNew(t *testing.T) {
 	s := view.NewReference(client.RefGVR)
 
-	require.NoError(t, s.Init(makeCtx()))
+	require.NoError(t, s.Init(makeCtx(t)))
 	assert.Equal(t, "References", s.Name())
 	assert.Len(t, s.Hints(), 4)
 }
