@@ -14,18 +14,18 @@ import (
 	"github.com/anchore/clio"
 	"github.com/anchore/grype/cmd/grype/cli/options"
 	"github.com/anchore/grype/grype"
-	"github.com/anchore/grype/grype/db/legacy/distribution"
-	v5 "github.com/anchore/grype/grype/db/v5"
-	"github.com/anchore/grype/grype/db/v5/matcher"
-	"github.com/anchore/grype/grype/db/v5/matcher/dotnet"
-	"github.com/anchore/grype/grype/db/v5/matcher/golang"
-	"github.com/anchore/grype/grype/db/v5/matcher/java"
-	"github.com/anchore/grype/grype/db/v5/matcher/javascript"
-	"github.com/anchore/grype/grype/db/v5/matcher/python"
-	"github.com/anchore/grype/grype/db/v5/matcher/ruby"
-	"github.com/anchore/grype/grype/db/v5/matcher/stock"
+	"github.com/anchore/grype/grype/match"
+	"github.com/anchore/grype/grype/matcher"
+	"github.com/anchore/grype/grype/matcher/dotnet"
+	"github.com/anchore/grype/grype/matcher/golang"
+	"github.com/anchore/grype/grype/matcher/java"
+	"github.com/anchore/grype/grype/matcher/javascript"
+	"github.com/anchore/grype/grype/matcher/python"
+	"github.com/anchore/grype/grype/matcher/ruby"
+	"github.com/anchore/grype/grype/matcher/stock"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vex"
+	"github.com/anchore/grype/grype/vulnerability"
 	"github.com/anchore/syft/syft"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/slogs"
@@ -40,8 +40,8 @@ const (
 )
 
 type imageScanner struct {
-	store       *v5.ProviderStore
-	dbStatus    *distribution.Status
+	provider    vulnerability.Provider
+	status      *vulnerability.ProviderStatus
 	opts        *options.Grype
 	scans       Scans
 	mx          sync.RWMutex
@@ -90,8 +90,9 @@ func (s *imageScanner) Init(name, version string) {
 	s.opts.GenerateMissingCPEs = true
 
 	var err error
-	s.store, s.dbStatus, err = grype.LoadVulnerabilityDB(
-		s.opts.DB.ToLegacyCuratorConfig(),
+	s.provider, s.status, err = grype.LoadVulnerabilityDB(
+		s.opts.ToClientConfig(),
+		s.opts.ToCuratorConfig(),
 		s.opts.DB.AutoUpdate,
 	)
 	if err != nil {
@@ -99,7 +100,7 @@ func (s *imageScanner) Init(name, version string) {
 		return
 	}
 
-	if e := validateDBLoad(err, s.dbStatus); e != nil {
+	if e := validateDBLoad(err, s.status); e != nil {
 		s.log.Error("VulDb validate failed", slogs.Error, e)
 		return
 	}
@@ -112,9 +113,9 @@ func (s *imageScanner) Stop() {
 	s.mx.RLock()
 	defer s.mx.RUnlock()
 
-	if s.store != nil {
-		_ = s.store.Close()
-		s.store = nil
+	if s.provider != nil {
+		_ = s.provider.Close()
+		s.provider = nil
 	}
 }
 
@@ -180,11 +181,11 @@ func (s *imageScanner) scan(_ context.Context, img string, sc *Scan) error {
 	}
 
 	v := grype.VulnerabilityMatcher{
-		Store:          *s.store,
-		IgnoreRules:    s.opts.Ignore,
-		NormalizeByCVE: s.opts.ByCVE,
-		FailSeverity:   s.opts.FailOnSeverity(),
-		Matchers:       getMatchers(s.opts),
+		VulnerabilityProvider: s.provider,
+		IgnoreRules:           s.opts.Ignore,
+		NormalizeByCVE:        s.opts.ByCVE,
+		FailSeverity:          s.opts.FailOnSeverity(),
+		Matchers:              getMatchers(s.opts),
 		VexProcessor: vex.NewProcessor(vex.ProcessorOptions{
 			Documents:   s.opts.VexDocuments,
 			IgnoreRules: s.opts.Ignore,
@@ -195,7 +196,7 @@ func (s *imageScanner) scan(_ context.Context, img string, sc *Scan) error {
 	if err != nil {
 		errs = errors.Join(errs, err)
 	}
-	if err := sc.run(mm, s.store); err != nil {
+	if err := sc.run(mm, s.provider); err != nil {
 		errs = errors.Join(errs, err)
 	}
 
@@ -218,7 +219,7 @@ func getProviderConfig(opts *options.Grype) pkg.ProviderConfig {
 	}
 }
 
-func getMatchers(opts *options.Grype) []matcher.Matcher {
+func getMatchers(opts *options.Grype) []match.Matcher {
 	return matcher.NewDefaultMatchers(
 		matcher.Config{
 			Java: java.MatcherConfig{
@@ -230,23 +231,23 @@ func getMatchers(opts *options.Grype) []matcher.Matcher {
 			Dotnet:     dotnet.MatcherConfig(opts.Match.Dotnet),
 			Javascript: javascript.MatcherConfig(opts.Match.Javascript),
 			Golang: golang.MatcherConfig{
-				UseCPEs:               opts.Match.Golang.UseCPEs,
-				AlwaysUseCPEForStdlib: opts.Match.Golang.AlwaysUseCPEForStdlib,
+				UseCPEs:                                opts.Match.Golang.UseCPEs,
+				AlwaysUseCPEForStdlib:                  opts.Match.Golang.AlwaysUseCPEForStdlib,
+				AllowMainModulePseudoVersionComparison: opts.Match.Golang.AllowMainModulePseudoVersionComparison,
 			},
 			Stock: stock.MatcherConfig(opts.Match.Stock),
 		},
 	)
 }
-
-func validateDBLoad(loadErr error, status *distribution.Status) error {
+func validateDBLoad(loadErr error, status *vulnerability.ProviderStatus) error {
 	if loadErr != nil {
 		return fmt.Errorf("failed to load vulnerability db: %w", loadErr)
 	}
 	if status == nil {
 		return fmt.Errorf("unable to determine the status of the vulnerability db")
 	}
-	if status.Err != nil {
-		return fmt.Errorf("db could not be loaded: %w", status.Err)
+	if status.Error != nil {
+		return fmt.Errorf("db could not be loaded: %w", status.Error)
 	}
 
 	return nil
